==> evtool-0.0.1.tar.gz: evtool-0.0.1/README.md <==
# evTool #

![PyPI](https://img.shields.io/pypi/v/evtool?color=%230A0) ![PyPI -
Downloads](https://img.shields.io/pypi/dm/evtool) [![Documentation
Status](https://readthedocs.org/projects/evtool/badge/?version=latest)](https://evtool.readthedocs.io/en/latest/?badge=latest)
![PyPI - License](https://img.shields.io/pypi/l/evtool?color=%230A0)

Analyse and display output from the binary stellar-evolution code ev (a.k.a. STARS and TWIN).
The code is being developed by [Marc van der Sluys](http://marc.vandersluys.nl) of the department of
Astrophysics at the Radboud University Nijmegen, the Institute of Nuclear and High-Energy Physics (Nikhef),
and the Institute for Gravitational and Subatomic Physics (GRASP) at Utrecht University, all in The
Netherlands.  The evTool package can be used under the conditions of the 
[EUPL 1.2](https://www.eupl.eu/1.2/en/) licence.


## Installation ##

This package can be installed using `pip install evtool`.  This should automatically install the
dependency packages `pandas`, if they haven't been installed already.  If you are
installing by hand, ensure that these packages are installed as well.


## Example use ##

```python
"""Example Python script using the evTool package."""

import evtool

```

## evTool pages ##

* [Pypi](https://pypi.org/project/evtool/): evTool Python package
* [GitHub](https://github.com/MarcvdSluys/evTool/): evTool source code
* [ReadTheDocs](https://evtool.readthedocs.io/): evTool documentation


## Author and licence ##

* Author: Marc van der Sluys
* Contact: http://marc.vandersluys.nl
* Licence: [EUPL 1.2](https://www.eupl.eu/1.2/en/)


## References ##


<sub>Copyright (c) 2023 Marc van der Sluys</sub>

==> evtool-0.0.3.tar.gz: evtool-0.0.3/README.md <==
# evTool #

![PyPI](https://img.shields.io/pypi/v/evtool?color=%230A0) ![PyPI -
Downloads](https://img.shields.io/pypi/dm/evtool) [![Documentation
Status](https://readthedocs.org/projects/evtool/badge/?version=latest)](https://evtool.readthedocs.io/en/latest/?badge=latest)
![PyPI - License](https://img.shields.io/pypi/l/evtool?color=%230A0)

Analyse and display output from the binary stellar-evolution code ev (a.k.a. STARS and TWIN).

The code is being developed by [Marc van der Sluys](http://marc.vandersluys.nl) of the Department of Physics
at Utrecht University in The Netherlands, and the Netherlands Institute of Nuclear and High-Energy Physics
(Nikhef) in Amsterdam.  The evTool package can be used under the conditions of the [EUPL
1.2](https://www.eupl.eu/1.2/en/) licence.


## Installation ##

This package can be installed using `pip install evtool`.  This should automatically install the
dependency packages `pandas`, if they haven't been installed already.  If you are
installing by hand, ensure that these packages are installed as well.


## Example use ##

```python
"""Example Python script using the evTool package."""

import evtool

```

## evTool pages ##

* [Pypi](https://pypi.org/project/evtool/): evTool Python package
* [GitHub](https://github.com/MarcvdSluys/evTool/): evTool source code
* [ReadTheDocs](https://evtool.readthedocs.io/): evTool documentation


## Author and licence ##

* Author: Marc van der Sluys
* Contact: http://marc.vandersluys.nl
* Licence: [EUPL 1.2](https://www.eupl.eu/1.2/en/)


## References ##


<sub>Copyright (c) 2023 Marc van der Sluys</sub>
